@@ -159,8 +159,8 @@ class Module:
                           }
                         }''')
             self.__normalized_values__ = np.array(response['data']['modules']['normalizedValues'])
-            _ss = [x['id'] for x in response['data']['modules']['sampleSets']['edges']['node']]
-            _bf = [x['id'] for x in response['data']['modules']['biofeatures']['edges']['node']]
+            _ss = [x['node']['id'] for x in response['data']['modules']['sampleSets']['edges']]
+            _bf = [x['node']['id'] for x in response['data']['modules']['biofeatures']['edges']]
             self.sample_sets = SampleSet.using(self.compendium).get(
                 filter={'id_In': str(_ss)}
             )
